@@ -1,4 +1,4 @@
-from cmdwordplay.__main__ import *
+from cmdwordplay import *
 import os
 旁白(["你醒了", "在一个洞里", "而你被眼前的场景吓了一跳——白色的骷髅头堆成了山", "但是你得赶紧出去"])
 选择([
